# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

try:
    from .workflow_refresh_schedule_py3 import WorkflowRefreshSchedule
    from .histogram_bin_py3 import HistogramBin
    from .quantiles_py3 import Quantiles
    from .moments_py3 import Moments
    from .value_count_py3 import ValueCount
    from .attribute_data_profile_py3 import AttributeDataProfile
    from .entity_data_profile_py3 import EntityDataProfile
    from .ci_result_py3 import CIResult
    from .api_error_result_py3 import ApiErrorResult
    from .attribute_semantic_information_py3 import AttributeSemanticInformation
    from .entity_enrichment_information_py3 import EntityEnrichmentInformation
    from .datasource_entity_information_py3 import DatasourceEntityInformation
    from .incremental_refresh_properties_py3 import IncrementalRefreshProperties
    from .data_source_metadata_py3 import DataSourceMetadata
    from .query_metadata_py3 import QueryMetadata
    from .mashup_py3 import Mashup
    from .annotation_py3 import Annotation
    from .entity_py3 import Entity
    from .relationship_py3 import Relationship
    from .reference_model_py3 import ReferenceModel
    from .model_py3 import Model
    from .data_source_info_py3 import DataSourceInfo
    from .ok_result_py3 import OkResult
    from .odata_error_detail_py3 import ODataErrorDetail
    from .odata_type_annotation_py3 import ODataTypeAnnotation
    from .odata_value_py3 import ODataValue
    from .odata_inner_error_py3 import ODataInnerError
    from .odata_instance_annotation_py3 import ODataInstanceAnnotation
    from .odata_error_py3 import ODataError
    from .created_result_py3 import CreatedResult
    from .accepted_result_py3 import AcceptedResult
    from .no_content_result_py3 import NoContentResult
    from .odata_entity_payload_py3 import ODataEntityPayload
    from .iedm_type_py3 import IEdmType
    from .iattribute_search_properties_py3 import IAttributeSearchProperties
    from .iattribute_metadata_py3 import IAttributeMetadata
    from .partition_metadata_py3 import PartitionMetadata
    from .ientity_metadata_py3 import IEntityMetadata
    from .irelationship_metadata_py3 import IRelationshipMetadata
    from .ic360_entity_model_py3 import IC360EntityModel
    from .entity_size_py3 import EntitySize
    from .hierarchy_dependency_py3 import HierarchyDependency
    from .hierarchy_metadata_py3 import HierarchyMetadata
    from .ok_object_result_py3 import OkObjectResult
    from .instance_info_py3 import InstanceInfo
    from .embedded_report_py3 import EmbeddedReport
    from .instance_provisioning_error_py3 import InstanceProvisioningError
    from .provisioning_status_py3 import ProvisioningStatus
    from .email_subscription_metadata_py3 import EmailSubscriptionMetadata
    from .data_refresh_schedule_py3 import DataRefreshSchedule
    from .trial_info_py3 import TrialInfo
    from .cds_org_info_py3 import CdsOrgInfo
    from .datalake_folder_detail_py3 import DatalakeFolderDetail
    from .cds_mdl_info_py3 import CdsMdlInfo
    from .pbi_provisioning_config_py3 import PbiProvisioningConfig
    from .trial_extension_details_py3 import TrialExtensionDetails
    from .instance_metadata_py3 import InstanceMetadata
    from .mapped_secret_metadata_py3 import MappedSecretMetadata
    from .resource_metadata_py3 import ResourceMetadata
    from .byo_pbi_provisioning_info_py3 import ByoPbiProvisioningInfo
    from .instance_creation_request_py3 import InstanceCreationRequest
    from .instance_copy_request_py3 import InstanceCopyRequest
    from .measure_linked_entity_py3 import MeasureLinkedEntity
    from .measure_variable_condition_py3 import MeasureVariableCondition
    from .measure_variable_condition_group_py3 import MeasureVariableConditionGroup
    from .measure_variable_py3 import MeasureVariable
    from .measure_expression_py3 import MeasureExpression
    from .segment_membership_criteria_py3 import SegmentMembershipCriteria
    from .measure_dimension_py3 import MeasureDimension
    from .measure_aggregate_py3 import MeasureAggregate
    from .activity_source_entity_info_py3 import ActivitySourceEntityInfo
    from .insight_activity_details_py3 import InsightActivityDetails
    from .entity_dependency_py3 import EntityDependency
    from .measure_definition_py3 import MeasureDefinition
    from .evaluation_py3 import Evaluation
    from .scalar_output_py3 import ScalarOutput
    from .evaluation_stats_py3 import EvaluationStats
    from .string_info_py3 import StringInfo
    from .sql_validation_stats_py3 import SqlValidationStats
    from .measure_metadata_py3 import MeasureMetadata
    from .source_location_py3 import SourceLocation
    from .log_message_py3 import LogMessage
    from .parsing_error_py3 import ParsingError
    from .key_ring_response_py3 import KeyRingResponse
    from .profile_store_module_run_info_py3 import ProfileStoreModuleRunInfo
    from .profile_store_collection_info_py3 import ProfileStoreCollectionInfo
    from .profile_store_state_info_py3 import ProfileStoreStateInfo
    from .role_definition_py3 import RoleDefinition
    from .role_assignment_py3 import RoleAssignment
    from .relationship_metadata_py3 import RelationshipMetadata
    from .attribute_search_properties_py3 import AttributeSearchProperties
    from .attribute_search_configuration_py3 import AttributeSearchConfiguration
    from .entity_search_configuration_py3 import EntitySearchConfiguration
    from .instance_search_configuration_py3 import InstanceSearchConfiguration
    from .segmentation_projection_py3 import SegmentationProjection
    from .segmentation_rowset_py3 import SegmentationRowset
    from .hierarchy_definition_py3 import HierarchyDefinition
    from .segmentation_query_py3 import SegmentationQuery
    from .segmentation_publish_stats_py3 import SegmentationPublishStats
    from .historical_segment_stats_py3 import HistoricalSegmentStats
    from .segment_rowset_stat_py3 import SegmentRowsetStat
    from .segment_query_stat_py3 import SegmentQueryStat
    from .segment_metadata_py3 import SegmentMetadata
    from .custom_task_information_py3 import CustomTaskInformation
    from .selection_reason_py3 import SelectionReason
    from .graph_task_info_py3 import GraphTaskInfo
    from .graph_job_options_py3 import GraphJobOptions
    from .graph_job_info_py3 import GraphJobInfo
    from .on_demand_job_request_py3 import OnDemandJobRequest
    from .data_info_py3 import DataInfo
    from .graph_node_info_py3 import GraphNodeInfo
    from .timezone_detail_py3 import TimezoneDetail
    from .dismissed_notification_py3 import DismissedNotification
    from .user_notifications_settings_py3 import UserNotificationsSettings
    from .history_py3 import History
    from .coachmarks_py3 import Coachmarks
    from .banners_py3 import Banners
    from .notifications_py3 import Notifications
    from .portal_settings_py3 import PortalSettings
    from .terms_of_use_py3 import TermsOfUse
    from .user_info_py3 import UserInfo
except (SyntaxError, ImportError):
    from .workflow_refresh_schedule import WorkflowRefreshSchedule
    from .histogram_bin import HistogramBin
    from .quantiles import Quantiles
    from .moments import Moments
    from .value_count import ValueCount
    from .attribute_data_profile import AttributeDataProfile
    from .entity_data_profile import EntityDataProfile
    from .ci_result import CIResult
    from .api_error_result import ApiErrorResult
    from .attribute_semantic_information import AttributeSemanticInformation
    from .entity_enrichment_information import EntityEnrichmentInformation
    from .datasource_entity_information import DatasourceEntityInformation
    from .incremental_refresh_properties import IncrementalRefreshProperties
    from .data_source_metadata import DataSourceMetadata
    from .query_metadata import QueryMetadata
    from .mashup import Mashup
    from .annotation import Annotation
    from .entity import Entity
    from .relationship import Relationship
    from .reference_model import ReferenceModel
    from .model import Model
    from .data_source_info import DataSourceInfo
    from .ok_result import OkResult
    from .odata_error_detail import ODataErrorDetail
    from .odata_type_annotation import ODataTypeAnnotation
    from .odata_value import ODataValue
    from .odata_inner_error import ODataInnerError
    from .odata_instance_annotation import ODataInstanceAnnotation
    from .odata_error import ODataError
    from .created_result import CreatedResult
    from .accepted_result import AcceptedResult
    from .no_content_result import NoContentResult
    from .odata_entity_payload import ODataEntityPayload
    from .iedm_type import IEdmType
    from .iattribute_search_properties import IAttributeSearchProperties
    from .iattribute_metadata import IAttributeMetadata
    from .partition_metadata import PartitionMetadata
    from .ientity_metadata import IEntityMetadata
    from .irelationship_metadata import IRelationshipMetadata
    from .ic360_entity_model import IC360EntityModel
    from .entity_size import EntitySize
    from .hierarchy_dependency import HierarchyDependency
    from .hierarchy_metadata import HierarchyMetadata
    from .ok_object_result import OkObjectResult
    from .instance_info import InstanceInfo
    from .embedded_report import EmbeddedReport
    from .instance_provisioning_error import InstanceProvisioningError
    from .provisioning_status import ProvisioningStatus
    from .email_subscription_metadata import EmailSubscriptionMetadata
    from .data_refresh_schedule import DataRefreshSchedule
    from .trial_info import TrialInfo
    from .cds_org_info import CdsOrgInfo
    from .datalake_folder_detail import DatalakeFolderDetail
    from .cds_mdl_info import CdsMdlInfo
    from .pbi_provisioning_config import PbiProvisioningConfig
    from .trial_extension_details import TrialExtensionDetails
    from .instance_metadata import InstanceMetadata
    from .mapped_secret_metadata import MappedSecretMetadata
    from .resource_metadata import ResourceMetadata
    from .byo_pbi_provisioning_info import ByoPbiProvisioningInfo
    from .instance_creation_request import InstanceCreationRequest
    from .instance_copy_request import InstanceCopyRequest
    from .measure_linked_entity import MeasureLinkedEntity
    from .measure_variable_condition import MeasureVariableCondition
    from .measure_variable_condition_group import MeasureVariableConditionGroup
    from .measure_variable import MeasureVariable
    from .measure_expression import MeasureExpression
    from .segment_membership_criteria import SegmentMembershipCriteria
    from .measure_dimension import MeasureDimension
    from .measure_aggregate import MeasureAggregate
    from .activity_source_entity_info import ActivitySourceEntityInfo
    from .insight_activity_details import InsightActivityDetails
    from .entity_dependency import EntityDependency
    from .measure_definition import MeasureDefinition
    from .evaluation import Evaluation
    from .scalar_output import ScalarOutput
    from .evaluation_stats import EvaluationStats
    from .string_info import StringInfo
    from .sql_validation_stats import SqlValidationStats
    from .measure_metadata import MeasureMetadata
    from .source_location import SourceLocation
    from .log_message import LogMessage
    from .parsing_error import ParsingError
    from .key_ring_response import KeyRingResponse
    from .profile_store_module_run_info import ProfileStoreModuleRunInfo
    from .profile_store_collection_info import ProfileStoreCollectionInfo
    from .profile_store_state_info import ProfileStoreStateInfo
    from .role_definition import RoleDefinition
    from .role_assignment import RoleAssignment
    from .relationship_metadata import RelationshipMetadata
    from .attribute_search_properties import AttributeSearchProperties
    from .attribute_search_configuration import AttributeSearchConfiguration
    from .entity_search_configuration import EntitySearchConfiguration
    from .instance_search_configuration import InstanceSearchConfiguration
    from .segmentation_projection import SegmentationProjection
    from .segmentation_rowset import SegmentationRowset
    from .hierarchy_definition import HierarchyDefinition
    from .segmentation_query import SegmentationQuery
    from .segmentation_publish_stats import SegmentationPublishStats
    from .historical_segment_stats import HistoricalSegmentStats
    from .segment_rowset_stat import SegmentRowsetStat
    from .segment_query_stat import SegmentQueryStat
    from .segment_metadata import SegmentMetadata
    from .custom_task_information import CustomTaskInformation
    from .selection_reason import SelectionReason
    from .graph_task_info import GraphTaskInfo
    from .graph_job_options import GraphJobOptions
    from .graph_job_info import GraphJobInfo
    from .on_demand_job_request import OnDemandJobRequest
    from .data_info import DataInfo
    from .graph_node_info import GraphNodeInfo
    from .timezone_detail import TimezoneDetail
    from .dismissed_notification import DismissedNotification
    from .user_notifications_settings import UserNotificationsSettings
    from .history import History
    from .coachmarks import Coachmarks
    from .banners import Banners
    from .notifications import Notifications
    from .portal_settings import PortalSettings
    from .terms_of_use import TermsOfUse
    from .user_info import UserInfo

__all__ = [
    'WorkflowRefreshSchedule',
    'HistogramBin',
    'Quantiles',
    'Moments',
    'ValueCount',
    'AttributeDataProfile',
    'EntityDataProfile',
    'CIResult',
    'ApiErrorResult',
    'AttributeSemanticInformation',
    'EntityEnrichmentInformation',
    'DatasourceEntityInformation',
    'IncrementalRefreshProperties',
    'DataSourceMetadata',
    'QueryMetadata',
    'Mashup',
    'Annotation',
    'Entity',
    'Relationship',
    'ReferenceModel',
    'Model',
    'DataSourceInfo',
    'OkResult',
    'ODataErrorDetail',
    'ODataTypeAnnotation',
    'ODataValue',
    'ODataInnerError',
    'ODataInstanceAnnotation',
    'ODataError',
    'CreatedResult',
    'AcceptedResult',
    'NoContentResult',
    'ODataEntityPayload',
    'IEdmType',
    'IAttributeSearchProperties',
    'IAttributeMetadata',
    'PartitionMetadata',
    'IEntityMetadata',
    'IRelationshipMetadata',
    'IC360EntityModel',
    'EntitySize',
    'HierarchyDependency',
    'HierarchyMetadata',
    'OkObjectResult',
    'InstanceInfo',
    'EmbeddedReport',
    'InstanceProvisioningError',
    'ProvisioningStatus',
    'EmailSubscriptionMetadata',
    'DataRefreshSchedule',
    'TrialInfo',
    'CdsOrgInfo',
    'DatalakeFolderDetail',
    'CdsMdlInfo',
    'PbiProvisioningConfig',
    'TrialExtensionDetails',
    'InstanceMetadata',
    'MappedSecretMetadata',
    'ResourceMetadata',
    'ByoPbiProvisioningInfo',
    'InstanceCreationRequest',
    'InstanceCopyRequest',
    'MeasureLinkedEntity',
    'MeasureVariableCondition',
    'MeasureVariableConditionGroup',
    'MeasureVariable',
    'MeasureExpression',
    'SegmentMembershipCriteria',
    'MeasureDimension',
    'MeasureAggregate',
    'ActivitySourceEntityInfo',
    'InsightActivityDetails',
    'EntityDependency',
    'MeasureDefinition',
    'Evaluation',
    'ScalarOutput',
    'EvaluationStats',
    'StringInfo',
    'SqlValidationStats',
    'MeasureMetadata',
    'SourceLocation',
    'LogMessage',
    'ParsingError',
    'KeyRingResponse',
    'ProfileStoreModuleRunInfo',
    'ProfileStoreCollectionInfo',
    'ProfileStoreStateInfo',
    'RoleDefinition',
    'RoleAssignment',
    'RelationshipMetadata',
    'AttributeSearchProperties',
    'AttributeSearchConfiguration',
    'EntitySearchConfiguration',
    'InstanceSearchConfiguration',
    'SegmentationProjection',
    'SegmentationRowset',
    'HierarchyDefinition',
    'SegmentationQuery',
    'SegmentationPublishStats',
    'HistoricalSegmentStats',
    'SegmentRowsetStat',
    'SegmentQueryStat',
    'SegmentMetadata',
    'CustomTaskInformation',
    'SelectionReason',
    'GraphTaskInfo',
    'GraphJobOptions',
    'GraphJobInfo',
    'OnDemandJobRequest',
    'DataInfo',
    'GraphNodeInfo',
    'TimezoneDetail',
    'DismissedNotification',
    'UserNotificationsSettings',
    'History',
    'Coachmarks',
    'Banners',
    'Notifications',
    'PortalSettings',
    'TermsOfUse',
    'UserInfo',
]



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CreatedResult(Model):
    """CreatedResult.

    :param location:
    :type location: str
    :param value:
    :type value: object
    :param formatters:
    :type formatters: list[object]
    :param content_types:
    :type content_types: list[str]
    :param declared_type:
    :type declared_type: str
    :param status_code:
    :type status_code: int
    """

    _attribute_map = {
        'location': {'key': 'location', 'type': 'str'},
        'value': {'key': 'value', 'type': 'object'},
        'formatters': {'key': 'formatters', 'type': '[object]'},
        'content_types': {'key': 'contentTypes', 'type': '[str]'},
        'declared_type': {'key': 'declaredType', 'type': 'str'},
        'status_code': {'key': 'statusCode', 'type': 'int'},
    }

    def __init__(self, *, location: str=None, value=None, formatters=None, content_types=None, declared_type: str=None, status_code: int=None, **kwargs) -> None:
        super(CreatedResult, self).__init__(**kwargs)
        self.location = location
        self.value = value
        self.formatters = formatters
        self.content_types = content_types
        self.declared_type = declared_type
        self.status_code = status_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProfileStoreStateInfo(Model):
    """Represents runtime profile store state.

    :param ingestion_time: Gets the latest date of ingestion.
    :type ingestion_time: datetime
    :param primary_info:
    :type primary_info:
     ~dynamics.customerinsights.api.models.ProfileStoreCollectionInfo
    :param secondary_info:
    :type secondary_info:
     ~dynamics.customerinsights.api.models.ProfileStoreCollectionInfo
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'ingestion_time': {'key': 'ingestionTime', 'type': 'iso-8601'},
        'primary_info': {'key': 'primaryInfo', 'type': 'ProfileStoreCollectionInfo'},
        'secondary_info': {'key': 'secondaryInfo', 'type': 'ProfileStoreCollectionInfo'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, *, ingestion_time=None, primary_info=None, secondary_info=None, instance_id: str=None, **kwargs) -> None:
        super(ProfileStoreStateInfo, self).__init__(**kwargs)
        self.ingestion_time = ingestion_time
        self.primary_info = primary_info
        self.secondary_info = secondary_info
        self.instance_id = instance_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ValueCount(Model):
    """A value and the count of that value.

    :param value: Represents the value.
    :type value: object
    :param count: Represents Count of the value.
    :type count: long
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': 'object'},
        'count': {'key': 'count', 'type': 'long'},
    }

    def __init__(self, **kwargs):
        super(ValueCount, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.count = kwargs.get('count', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProvisioningStatus(Model):
    """Represents the status of a provisioning operation.

    :param total_steps: Gets the total number of steps in the provisioning
     operation.
    :type total_steps: int
    :param current_step: Gets the current step in the provisioning operation.
    :type current_step: int
    :param current_operation: Possible values include: 'starting', 'creating',
     'loadingData', 'completed'
    :type current_operation: str or ~dynamics.customerinsights.api.models.enum
    :param created_time_utc: Gets the instance created time.
    :type created_time_utc: datetime
    :param last_updated_time_utc: Gets the instance last updated time.
    :type last_updated_time_utc: datetime
    :param errors: Gets a list of provisioning errors.
    :type errors:
     list[~dynamics.customerinsights.api.models.InstanceProvisioningError]
    """

    _attribute_map = {
        'total_steps': {'key': 'totalSteps', 'type': 'int'},
        'current_step': {'key': 'currentStep', 'type': 'int'},
        'current_operation': {'key': 'currentOperation', 'type': 'str'},
        'created_time_utc': {'key': 'createdTimeUtc', 'type': 'iso-8601'},
        'last_updated_time_utc': {'key': 'lastUpdatedTimeUtc', 'type': 'iso-8601'},
        'errors': {'key': 'errors', 'type': '[InstanceProvisioningError]'},
    }

    def __init__(self, *, total_steps: int=None, current_step: int=None, current_operation=None, created_time_utc=None, last_updated_time_utc=None, errors=None, **kwargs) -> None:
        super(ProvisioningStatus, self).__init__(**kwargs)
        self.total_steps = total_steps
        self.current_step = current_step
        self.current_operation = current_operation
        self.created_time_utc = created_time_utc
        self.last_updated_time_utc = last_updated_time_utc
        self.errors = errors



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IAttributeMetadata(Model):
    """Represents attribute Metadata.

    :param name: Unique Name for Attribute Metadata
    :type name: str
    :param friendly_name: User friendly Name for Attribute Metadata
    :type friendly_name: str
    :param base_name: Base Name for Attribute Metadata
    :type base_name: str
    :param data_type: Gets data type for property.
    :type data_type: str
    :param semantic_type: Gets semantic type for property. Possible values
     include: 'CalendarDate', 'CalendarDayOfMonth', 'CalendarDayOfWeek',
     'CalendarDayOfYear', 'CalendarHalfYear', 'CalendarMonthOfYear',
     'CalendarMonth', 'CalendarWeek', 'CalendarYear', 'CalendarFiscalDate',
     'CalendarFiscalDayOfMonth', 'CalendarFiscalDayOfWeek',
     'CalendarFiscalDayOfYear', 'CalendarFiscalHalfYear',
     'CalendarFiscalMonthOfYear', 'CalendarFiscalMonth',
     'CalendarFiscalQuarter', 'CalendarFiscalWeekOfMonth',
     'CalendarFiscalWeekOfYear', 'CalendarFiscalWeek', 'CalendarFiscalYear',
     'Account', 'Channel', 'Contact', 'Customer', 'Language', 'Organization',
     'OrganizationUnit', 'Person', 'Product', 'ProductGroup',
     'LocationAddress', 'LocationAddressStreet', 'LocationCity',
     'LocationContinent', 'LocationCountry', 'LocationCounty',
     'LocationLatitude', 'LocationLongitude', 'LocationPoint',
     'LocationPostalCode', 'LocationProvince', 'LocationRegion',
     'LocationState', 'LocationTimezone', 'MeasurementDateCreation',
     'MeasurementDateModify', 'MeasurementStatus', 'MeasurementVersion',
     'BarCode', 'Brand', 'IdentityGovernmentID', 'PersonFirstName',
     'PersonFullName', 'PersonLastName', 'PersonMiddleName',
     'IdentityServiceEmail', 'IdentityServiceFacebook', 'IdentityServicePhone',
     'IdentityServiceTwitter', 'Image', 'Place', 'ReferenceDescription',
     'ReferenceImageURL', 'ReferencePhonetic', 'ReferenceURL'
    :type semantic_type: str or ~dynamics.customerinsights.api.models.enum
    :param search_properties:
    :type search_properties:
     ~dynamics.customerinsights.api.models.IAttributeSearchProperties
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'friendly_name': {'key': 'friendlyName', 'type': 'str'},
        'base_name': {'key': 'baseName', 'type': 'str'},
        'data_type': {'key': 'dataType', 'type': 'str'},
        'semantic_type': {'key': 'semanticType', 'type': 'str'},
        'search_properties': {'key': 'searchProperties', 'type': 'IAttributeSearchProperties'},
    }

    def __init__(self, **kwargs):
        super(IAttributeMetadata, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.friendly_name = kwargs.get('friendly_name', None)
        self.base_name = kwargs.get('base_name', None)
        self.data_type = kwargs.get('data_type', None)
        self.semantic_type = kwargs.get('semantic_type', None)
        self.search_properties = kwargs.get('search_properties', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SegmentRowsetStat(Model):
    """Represents a SegmentRowset Stat.

    :param rowset_id: Gets a Rowset Id for the Rowset Stat.
    :type rowset_id: str
    :param rowset_count: Gets a Rowset Count for the Rowset Id.
    :type rowset_count: long
    """

    _attribute_map = {
        'rowset_id': {'key': 'rowsetId', 'type': 'str'},
        'rowset_count': {'key': 'rowsetCount', 'type': 'long'},
    }

    def __init__(self, *, rowset_id: str=None, rowset_count: int=None, **kwargs) -> None:
        super(SegmentRowsetStat, self).__init__(**kwargs)
        self.rowset_id = rowset_id
        self.rowset_count = rowset_count



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SegmentMetadata(Model):
    """Represents a base Segment Metadata.

    :param kind: Possible values include: 'default', 'engagement'
    :type kind: str or ~dynamics.customerinsights.api.models.enum
    :param name: Gets the unique name of the segment
    :type name: str
    :param friendly_name: Gets the friendlyName of the segment.
    :type friendly_name: str
    :param description: Gets the description of the segment.
    :type description: str
    :param segment_query_expression:
    :type segment_query_expression:
     ~dynamics.customerinsights.api.models.SegmentationQuery
    :param state: Possible values include: 'inactive', 'active', 'validating',
     'validated', 'invalid', 'validationError'
    :type state: str or ~dynamics.customerinsights.api.models.enum
    :param error_description: Gets the error description when the segment
     metadata has some issues after refresh.
    :type error_description: str
    :param end_date: Gets the end date of the segment.
    :type end_date: datetime
    :param evaluation_status:
    :type evaluation_status:
     ~dynamics.customerinsights.api.models.SegmentationPublishStats
    :param sql_validation_stats:
    :type sql_validation_stats:
     ~dynamics.customerinsights.api.models.SqlValidationStats
    :param evaluation_status_history: Gets the segment evaluation status
     history. (not persisted in store)
    :type evaluation_status_history:
     list[~dynamics.customerinsights.api.models.HistoricalSegmentStats]
    :param segment_query_stats:
    :type segment_query_stats:
     ~dynamics.customerinsights.api.models.SegmentQueryStat
    :param version: Version number of this object.
    :type version: long
    :param updated_by: UPN of the user who last updated this record.
    :type updated_by: str
    :param updated_utc: Time this object was last updated.
    :type updated_utc: datetime
    :param created_by: Email address of the user who created this record.
    :type created_by: str
    :param created_utc: Time this object was initially created.
    :type created_utc: datetime
    :param instance_id: Customer Insights instance id associated with this
     object.
    :type instance_id: str
    """

    _attribute_map = {
        'kind': {'key': 'kind', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'friendly_name': {'key': 'friendlyName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'segment_query_expression': {'key': 'segmentQueryExpression', 'type': 'SegmentationQuery'},
        'state': {'key': 'state', 'type': 'str'},
        'error_description': {'key': 'errorDescription', 'type': 'str'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'evaluation_status': {'key': 'evaluationStatus', 'type': 'SegmentationPublishStats'},
        'sql_validation_stats': {'key': 'sqlValidationStats', 'type': 'SqlValidationStats'},
        'evaluation_status_history': {'key': 'evaluationStatusHistory', 'type': '[HistoricalSegmentStats]'},
        'segment_query_stats': {'key': 'segmentQueryStats', 'type': 'SegmentQueryStat'},
        'version': {'key': 'version', 'type': 'long'},
        'updated_by': {'key': 'updatedBy', 'type': 'str'},
        'updated_utc': {'key': 'updatedUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'instance_id': {'key': 'instanceId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(SegmentMetadata, self).__init__(**kwargs)
        self.kind = kwargs.get('kind', None)
        self.name = kwargs.get('name', None)
        self.friendly_name = kwargs.get('friendly_name', None)
        self.description = kwargs.get('description', None)
        self.segment_query_expression = kwargs.get('segment_query_expression', None)
        self.state = kwargs.get('state', None)
        self.error_description = kwargs.get('error_description', None)
        self.end_date = kwargs.get('end_date', None)
        self.evaluation_status = kwargs.get('evaluation_status', None)
        self.sql_validation_stats = kwargs.get('sql_validation_stats', None)
        self.evaluation_status_history = kwargs.get('evaluation_status_history', None)
        self.segment_query_stats = kwargs.get('segment_query_stats', None)
        self.version = kwargs.get('version', None)
        self.updated_by = kwargs.get('updated_by', None)
        self.updated_utc = kwargs.get('updated_utc', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_utc = kwargs.get('created_utc', None)
        self.instance_id = kwargs.get('instance_id', None)
